@@ -21,51 +21,21 @@ from django.utils.text import slugify
 from reversion.models import Version
 from watson import search
 
+from cms.apps.testing_models.admin import (TestInlineModelInline, TestInlineModelNoPageInline)
+from cms.apps.testing_models.models import (TestInlineModel, TestInlineModelNoPage,
+                                            TestPageContent, TestPageContentWithFields)
+
 from ..admin import (PAGE_FROM_KEY, PAGE_FROM_SITEMAP_VALUE,
                      PAGE_TYPE_PARAMETER, PageAdmin, PageContentTypeFilter)
 from ..models import (ContentBase, Country, CountryGroup, Page,
                       get_registered_content)
 
 
-# Test models
-class PageContent(ContentBase):
+class MockRequest:
     pass
 
 
-class PageContentWithFields(ContentBase):
-    description = models.TextField(
-        blank=True,
-    )
-
-    inline_model = models.ManyToManyField(
-        'InlineModelNoPage',
-        blank=True,
-    )
-
-
-class InlineModel(models.Model):
-    page = models.ForeignKey(Page)
-
-
-class InlineModelNoPage(models.Model):
-    pass
-
-
-# Test model admins
-class InlineModelNoPageInline(admin.StackedInline):
-    model = InlineModelNoPage
-
-
-class InlineModelInline(admin.StackedInline):
-    model = InlineModel
-
-
-# Other test classes
-class MockRequest(object):
-    pass
-
-
-class MockSuperUser(object):
+class MockSuperUser:
     pk = 1
     is_active = True
     is_staff = True
@@ -74,16 +44,6 @@ class MockSuperUser(object):
         return True
 
 
-def get_inline_instances_1_4_x(self, request):
-    inline_instances = []
-    for inline_class in self.inlines:
-        inline = inline_class(self.model, self.admin_site)
-        inline.max_num = 0
-        inline_instances.append(inline)
-
-    return inline_instances
-
-
 class TestPageAdmin(TestCase):
 
     maxDiff = None
@@ -93,7 +53,7 @@ class TestPageAdmin(TestCase):
         self.page_admin = PageAdmin(Page, self.site)
 
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContent)
+            content_type = ContentType.objects.get_for_model(TestPageContent)
 
             self.homepage = Page.objects.create(
                 title="Homepage",
@@ -101,7 +61,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContent.objects.create(
+            TestPageContent.objects.create(
                 page=self.homepage,
             )
 
@@ -126,17 +86,17 @@ class TestPageAdmin(TestCase):
         return request
 
     def _make_page(self, title, content_type):
-            ''' Little helper to create a page whose parent is the homepage. '''
-            content_page = Page.objects.create(
-                title=title,
-                slug=slugify(title),
-                parent=self.homepage,
-                content_type=content_type,
-            )
+        ''' Little helper to create a page whose parent is the homepage. '''
+        content_page = Page.objects.create(
+            title=title,
+            slug=slugify(title),
+            parent=self.homepage,
+            content_type=content_type,
+        )
 
-            content_type.model_class().objects.create(
-                page=content_page,
-            )
+        content_type.model_class().objects.create(
+            page=content_page,
+        )
 
     def test_pageadmin_get_object(self):
         factory = RequestFactory()
@@ -144,52 +104,28 @@ class TestPageAdmin(TestCase):
         self.assertEqual(self.page_admin.get_object(request, -1), None)
 
     def test_pageadmin_register_page_inline(self):
-        self.page_admin._register_page_inline(InlineModelNoPage)
+        self.page_admin._register_page_inline(TestInlineModelNoPage)
 
     def test_pageadmin_register_content_inline(self):
         self.assertListEqual(self.page_admin.content_inlines, [])
 
-        self.page_admin.register_content_inline(PageContent, InlineModelInline)
+        self.page_admin.register_content_inline(TestPageContent, TestInlineModelInline)
 
-        self.assertListEqual(self.page_admin.content_inlines, [(PageContent, InlineModelInline), ])
-
-    def test_get_inline_instances_1_4_x(self):
-        class Inlines(object):
-            model = PageContent
-            admin_site = self.page_admin
-
-            def __init__(self, *args, **kwargs):
-                self.inlines = kwargs.get('inlines', [])
-
-        factory = RequestFactory()
-        request = factory.get('/')
-
-        self.assertListEqual(get_inline_instances_1_4_x(Inlines(), request), [])
-        self.assertEqual(len(get_inline_instances_1_4_x(Inlines(inlines=[InlineModel]), request)), 1)
+        self.assertListEqual(self.page_admin.content_inlines, [(TestPageContent, TestInlineModelInline), ])
 
     def test_pageadmin_get_inline_instances(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
 
         self.assertListEqual(self.page_admin.get_inline_instances(request), [])
         self.assertListEqual(self.page_admin.get_inline_instances(request, obj=self.homepage), [])
-        self.page_admin.register_content_inline(PageContent, InlineModelInline)
+        self.page_admin.register_content_inline(TestPageContent, TestInlineModelInline)
         self.assertEqual(len(self.page_admin.get_inline_instances(request, obj=self.homepage)), 1)
 
-        # Monkey patch the function back to Django 1.4.x style so we can trigger
-        # the TypeError in `PageAdmin.get_inline_instances`.
-        initial_instances = getattr(admin.ModelAdmin, 'get_inline_instances')
-        setattr(admin.ModelAdmin, 'get_inline_instances', get_inline_instances_1_4_x)
-
-        self.assertEqual(len(self.page_admin.get_inline_instances(request, obj=self.homepage)), 1)
-
-        # Put the method back to what is was.
-        setattr(admin.ModelAdmin, 'get_inline_instances', initial_instances)
-
     def test_pageadmin_get_revision_instances(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
 
         instances = self.page_admin.get_revision_instances(request, self.homepage)
@@ -197,14 +133,14 @@ class TestPageAdmin(TestCase):
 
         # Register a content type which doesn't have a `page` attribute to
         # trigger the exception in `get_revision_instances`.
-        self.page_admin.register_content_inline(PageContent, InlineModelNoPageInline)
+        self.page_admin.register_content_inline(TestPageContent, TestInlineModelNoPageInline)
 
         instances = self.page_admin.get_revision_instances(request, self.homepage)
         self.assertListEqual(instances, [self.homepage, self.homepage.content])
 
     def test_pageadmin_get_revision_form_data(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
 
         # Create an initial revision.
@@ -218,28 +154,28 @@ class TestPageAdmin(TestCase):
 
     def test_pageadmin_get_page_content_cls(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
 
         request2 = self._build_request()
 
-        self.assertEqual(self.page_admin.get_page_content_cls(request), PageContent)
+        self.assertEqual(self.page_admin.get_page_content_cls(request), TestPageContent)
 
         with self.assertRaises(Http404):
             self.page_admin.get_page_content_cls(request2)
 
-        self.assertEqual(self.page_admin.get_page_content_cls(request2, self.homepage), PageContent)
+        self.assertEqual(self.page_admin.get_page_content_cls(request2, self.homepage), TestPageContent)
 
     def test_pageadmin_get_fieldsets(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
         request2 = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContentWithFields).pk
+            page_type=ContentType.objects.get_for_model(TestPageContentWithFields).pk
         )
 
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self.content_page = Page.objects.create(
                 title="Content page",
@@ -248,7 +184,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContentWithFields.objects.create(
+            TestPageContentWithFields.objects.create(
                 page=self.content_page,
             )
 
@@ -267,7 +203,7 @@ class TestPageAdmin(TestCase):
                 'fields': ('short_title', 'in_navigation', "hide_from_anonymous",),
                 'classes': ('collapse',)
             }),
-            ('Search engine optimization', {
+            ('SEO', {
                 'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
             }),
@@ -299,7 +235,7 @@ class TestPageAdmin(TestCase):
                 'fields': ('short_title', 'in_navigation', "hide_from_anonymous",),
                 'classes': ('collapse',)
             }),
-            ('Search engine optimization', {
+            ('SEO', {
                 'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
             }),
@@ -321,7 +257,7 @@ class TestPageAdmin(TestCase):
 
         # Add a child page.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self.content_page = Page.objects.create(
                 title="Content page",
@@ -330,7 +266,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContentWithFields.objects.create(
+            TestPageContentWithFields.objects.create(
                 page=self.content_page,
             )
 
@@ -344,7 +280,7 @@ class TestPageAdmin(TestCase):
 
     def test_pageadmin_get_form(self):
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContent).pk
+            page_type=ContentType.objects.get_for_model(TestPageContent).pk
         )
 
         form = self.page_admin.get_form(request)
@@ -363,7 +299,7 @@ class TestPageAdmin(TestCase):
 
         # Test a page with a content model with fields.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self.content_page = Page.objects.create(
                 title="Content page",
@@ -372,7 +308,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContentWithFields.objects.create(
+            TestPageContentWithFields.objects.create(
                 page=self.content_page,
             )
 
@@ -390,7 +326,7 @@ class TestPageAdmin(TestCase):
 
         self.assertIsInstance(form.base_fields['inline_model'].widget, RelatedFieldWidgetWrapper)
 
-        setattr(PageContentWithFields, 'filter_horizontal', ['inline_model'])
+        setattr(TestPageContentWithFields, 'filter_horizontal', ['inline_model'])
         form = self.page_admin.get_form(request, obj=self.content_page)
         self.assertIsInstance(form.base_fields['inline_model'].widget, FilteredSelectMultiple)
 
@@ -421,7 +357,7 @@ class TestPageAdmin(TestCase):
         # Trigger the `content_cls.DoesNotExist` exception.
         content_cls = self.page_admin.get_page_content_cls(request, self.content_page)
 
-        class Obj(object):
+        class Obj:
 
             def __getattr__(self, name):
                 return getattr(self.page, name)
@@ -440,7 +376,7 @@ class TestPageAdmin(TestCase):
         # NOTE: This page type is different to the one used by the homepage.
         # This is intentional to test certain conditional routes in the method.
         request = self._build_request(
-            page_type=ContentType.objects.get_for_model(PageContentWithFields).pk
+            page_type=ContentType.objects.get_for_model(TestPageContentWithFields).pk
         )
 
         form = self.page_admin.get_form(request)(data={
@@ -450,7 +386,7 @@ class TestPageAdmin(TestCase):
         })
         form.is_valid()
 
-        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(PageContent).pk)
+        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(TestPageContent).pk)
 
         with self.assertRaises(AttributeError):
             self.homepage.content.description
@@ -458,11 +394,11 @@ class TestPageAdmin(TestCase):
         # Save the model
         self.page_admin.save_model(request, self.homepage, form, True)
 
-        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(PageContentWithFields).pk)
+        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(TestPageContentWithFields).pk)
         self.assertEqual(self.homepage.content.description, 'Foo')
 
         self.page_admin.save_model(request, self.homepage, form, False)
-        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(PageContentWithFields).pk)
+        self.assertEqual(self.homepage.content_type_id, ContentType.objects.get_for_model(TestPageContentWithFields).pk)
         self.assertEqual(self.homepage.content.description, 'Foo')
 
     def test_pageadmin_has_add_content_permissions(self):
@@ -554,11 +490,7 @@ class TestPageAdmin(TestCase):
 
         response = self.page_admin.change_view(request, str(self.homepage.pk))
 
-        NEW_MIDDLEWARE_CLASSES = [
-            'cms.middleware.LocalisationMiddleware',
-        ] + list(settings.MIDDLEWARE_CLASSES)
-
-        with self.settings(MIDDLEWARE_CLASSES=NEW_MIDDLEWARE_CLASSES):
+        with self.settings(MIDDLEWARE=['cms.middleware.LocalisationMiddleware']):
             request = self._build_request()
             response = self.page_admin.change_view(request, str(self.homepage.pk))
             self.assertEqual(response.status_code, 200)
@@ -583,7 +515,7 @@ class TestPageAdmin(TestCase):
 
         models = get_registered_content()
         for content in get_registered_content():
-            if content != PageContent:
+            if content != TestPageContent:
                 content._meta.abstract = True
 
         response = self.page_admin.add_view(request)
@@ -592,12 +524,12 @@ class TestPageAdmin(TestCase):
         for model in models:
             model._meta.abstract = False
 
-        request.GET[PAGE_TYPE_PARAMETER] = ContentType.objects.get_for_model(PageContent).pk
+        request.GET[PAGE_TYPE_PARAMETER] = ContentType.objects.get_for_model(TestPageContent).pk
         response = self.page_admin.add_view(request)
         self.assertEqual(response.status_code, 200)
 
         request.user.has_perm = lambda x: False
-        request.GET[PAGE_TYPE_PARAMETER] = ContentType.objects.get_for_model(PageContent).pk
+        request.GET[PAGE_TYPE_PARAMETER] = ContentType.objects.get_for_model(TestPageContent).pk
 
         with self.assertRaises(PermissionDenied):
             response = self.page_admin.add_view(request)
@@ -651,7 +583,7 @@ class TestPageAdmin(TestCase):
 
         # Add a child page.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self.content_page = Page.objects.create(
                 title="Content page",
@@ -660,7 +592,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContentWithFields.objects.create(
+            TestPageContentWithFields.objects.create(
                 page=self.content_page,
             )
 
@@ -703,7 +635,7 @@ class TestPageAdmin(TestCase):
 
         # Add some child pages.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContent)
+            content_type = ContentType.objects.get_for_model(TestPageContent)
 
             content_page_1 = Page.objects.create(
                 title="Foo",
@@ -712,7 +644,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContent.objects.create(
+            TestPageContent.objects.create(
                 page=content_page_1,
             )
 
@@ -725,7 +657,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContent.objects.create(
+            TestPageContent.objects.create(
                 page=alternative_page,
             )
 
@@ -736,7 +668,7 @@ class TestPageAdmin(TestCase):
                 content_type=content_type,
             )
 
-            PageContent.objects.create(
+            TestPageContent.objects.create(
                 page=content_page_2,
             )
 
@@ -773,10 +705,7 @@ class TestPageAdmin(TestCase):
         self.assertEqual(content_page_2.left, 2)
         self.assertEqual(content_page_2.right, 3)
 
-        if six.PY2:
-            self.assertEqual(response.content, "Page #" + six.text_type(content_page_1.pk) + " was moved down.")
-        else:
-            self.assertEqual(response.content, bytes("Page #" + six.text_type(content_page_1.pk) + " was moved down.", 'utf-8'))
+        self.assertEqual(response.content, bytes("Page #" + str(content_page_1.pk) + " was moved down.", 'utf-8'))
         self.assertEqual(response.status_code, 200)
 
         request.user.has_perm = lambda x: False
@@ -823,12 +752,12 @@ class TestPageAdmin(TestCase):
             country_group=self.country_group.pk
         )
         response = self.page_admin.duplicate_for_country_group(request, page=self.homepage.pk)
-        self.assertEquals(Page.objects.filter(owner=self.homepage, is_content_object=True).count(), 1)
+        self.assertEqual(Page.objects.filter(owner=self.homepage, is_content_object=True).count(), 1)
 
         with search.update_index():
 
             content_type_2 = ContentType.objects.get_for_model(
-                PageContentWithFields)
+                TestPageContentWithFields)
 
             inline_page = Page.objects.create(
                 parent=self.homepage,
@@ -836,11 +765,11 @@ class TestPageAdmin(TestCase):
                 content_type=content_type_2,
             )
 
-            PageContentWithFields.objects.create(
+            TestPageContentWithFields.objects.create(
                 page=inline_page,
             )
 
-            inline_model = InlineModel.objects.create(
+            inline_model = TestInlineModel.objects.create(
                 page=inline_page,
             )
 
@@ -849,11 +778,11 @@ class TestPageAdmin(TestCase):
                 country_group=self.country_group.pk
             )
             response = self.page_admin.duplicate_for_country_group(request, page=inline_page.pk)
-            self.assertEquals(Page.objects.filter(owner=inline_page, is_content_object=True).count(), 1)
+            self.assertEqual(Page.objects.filter(owner=inline_page, is_content_object=True).count(), 1)
 
             inline_page_clone = Page.objects.get(owner=inline_page, is_content_object=True)
 
-            self.assertEquals(inline_page_clone.inlinemodel_set.count(), 1)
+            self.assertEqual(inline_page_clone.testinlinemodel_set.count(), 1)
 
     def test_pagecontenttypefilter_queryset(self):
         # Ensures that the queryset returned by filtering is correct.
@@ -861,8 +790,8 @@ class TestPageAdmin(TestCase):
 
         # Add some pages with different content types.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContent)
-            content_type_2 = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContent)
+            content_type_2 = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self._make_page('Food', content_type)
             self._make_page('Barred', content_type)
@@ -875,7 +804,7 @@ class TestPageAdmin(TestCase):
 
         # Test with a content type filter. It should return a subset of the
         # pages.
-        content_type_id = ContentType.objects.get_for_model(PageContent).id
+        content_type_id = ContentType.objects.get_for_model(TestPageContent).id
         parameters = {'page_type': content_type_id}
         filterer = PageContentTypeFilter(request, parameters, Page, self.page_admin)
         queryset = filterer.queryset(request, Page.objects.all())
@@ -893,8 +822,8 @@ class TestPageAdmin(TestCase):
     def test_pagecontenttypefilter_lookups(self):
         # Add some pages with different content types.
         with search.update_index():
-            content_type = ContentType.objects.get_for_model(PageContent)
-            content_type_2 = ContentType.objects.get_for_model(PageContentWithFields)
+            content_type = ContentType.objects.get_for_model(TestPageContent)
+            content_type_2 = ContentType.objects.get_for_model(TestPageContentWithFields)
 
             self._make_page('John', content_type)
             self._make_page('Paul', content_type)
